# This class just hold the global singletons for the bot outside of the plugin framework to avoid spurrious modules reloads
plugin_manager = None
bot = None
